@@ -286,6 +286,7 @@ def do_discovery(conn_config, filter_schemas):
    cur = connection.cursor()
 
    if conn_config['multitenant']:
+      LOGGER.info("DB is multitenant")
       cur.execute(f"ALTER SESSION SET CONTAINER = {conn_config['pdb_name']}") #Switch to expected PDB
 
    row_counts = produce_row_counts(cur, filter_schemas)
@@ -324,14 +325,20 @@ def do_discovery(conn_config, filter_schemas):
    for row in cur.execute(sql, filter_schemas):
      view_name = row[1]
      schema = row[0]
+     
      if schema not in table_info:
         table_info[schema] = {}
 
      table_info[schema][view_name] = {
         'is_view': True
      }
+   
+   
+   for scheme in table_info.keys():
+      LOGGER.info(f"Found {len(table_info[scheme])} tables/views in schema {scheme}")
 
    catalog = discover_columns(cur, table_info, filter_schemas)
+   
    dump_catalog(catalog)
    cur.close()
    connection.close()
